@@ -34,6 +34,7 @@
 #include <glib/gi18n.h>
 
 #include <langinfo.h>
+#include <locale.h>
 
 #include <string.h>
 #include <math.h>
@@ -1041,18 +1042,14 @@ is_workday (guint day)
 
   no_work_days = GCAL_WEEK_DAY_SATURDAY | GCAL_WEEK_DAY_SUNDAY;
 
-  locale = getenv ("LC_ALL");
-  if (!locale || g_utf8_strlen (locale, -1) < 5)
-    locale = getenv ("LC_TIME");
+  locale = setlocale (LC_TIME, NULL);
 
-  if (!locale)
+  if (!locale || g_utf8_strlen (locale, -1) < 5)
     {
-      g_warning ("Locale is NULL, assuming Saturday and Sunday as non workdays");
+      g_warning ("Locale is unset or lacks territory code, assuming Saturday and Sunday as non workdays");
       return !(no_work_days & 1 << day);
     }
 
-  g_return_val_if_fail (g_utf8_strlen (locale, -1) >= 5, TRUE);
-
   territory[0] = locale[3];
   territory[1] = locale[4];
 
@@ -1188,3 +1185,81 @@ gcal_translate_child_window_position (GtkWidget *target,
 
   return TRUE;
 }
+
+void
+gcal_utils_launch_online_accounts_panel (GDBusConnection *connection,
+                                         const gchar     *action,
+                                         const gchar     *arg)
+{
+  g_autoptr (GDBusProxy) proxy = NULL;
+  GVariantBuilder builder;
+  GVariant *params[3];
+  GVariant *array[1];
+
+  g_variant_builder_init (&builder, G_VARIANT_TYPE ("av"));
+
+  if (!action && !arg)
+    {
+      g_variant_builder_add (&builder, "v", g_variant_new_string (""));
+    }
+  else
+    {
+      if (action)
+        g_variant_builder_add (&builder, "v", g_variant_new_string (action));
+
+      if (arg)
+        g_variant_builder_add (&builder, "v", g_variant_new_string (arg));
+    }
+
+  array[0] = g_variant_new ("v", g_variant_new ("(sav)", "online-accounts", &builder));
+
+  params[0] = g_variant_new_string ("launch-panel");
+  params[1] = g_variant_new_array (G_VARIANT_TYPE ("v"), array, 1);
+  params[2] = g_variant_new_array (G_VARIANT_TYPE ("{sv}"), NULL, 0);
+
+  proxy = g_dbus_proxy_new_sync (connection,
+                                 G_DBUS_PROXY_FLAGS_NONE,
+                                 NULL,
+                                 "org.gnome.ControlCenter",
+                                 "/org/gnome/ControlCenter",
+                                 "org.gtk.Actions",
+                                 NULL,
+                                 NULL);
+
+  if (!proxy)
+    {
+      g_warning ("Couldn't open Online Accounts panel");
+      return;
+    }
+
+  g_dbus_proxy_call_sync (proxy,
+                          "Activate",
+                          g_variant_new_tuple (params, 3),
+                          G_DBUS_CALL_FLAGS_NONE,
+                          -1,
+                          NULL,
+                          NULL);
+}
+
+gchar*
+gcal_utils_format_filename_for_display (const gchar *filename)
+{
+  /*
+   * Foo_bar-something-cool.ics
+   */
+  g_autofree gchar *display_name = NULL;
+  gchar *file_extension;
+
+  display_name = g_strdup (filename);
+
+  /* Strip out the file extension */
+  file_extension = g_strrstr (display_name, ".");
+  if (file_extension)
+    *file_extension = '\0';
+
+  /* Replace underscores with spaces */
+  display_name = g_strdelimit (display_name, "_", ' ');
+  display_name = g_strstrip (display_name);
+
+  return g_steal_pointer (&display_name);
+}
