@@ -19,6 +19,9 @@
 
 #define G_LOG_DOMAIN "GcalWeekGrid"
 
+#include "gcal-application.h"
+#include "gcal-clock.h"
+#include "gcal-context.h"
 #include "gcal-debug.h"
 #include "gcal-week-grid.h"
 #include "gcal-week-view.h"
@@ -51,7 +54,7 @@ struct _GcalWeekGrid
   GtkWidget          *hours_sidebar;
   GdkWindow          *event_window;
 
-  icaltimetype       *active_date;
+  GDateTime          *active_date;
 
   GcalRangeTree      *events;
 
@@ -63,7 +66,7 @@ struct _GcalWeekGrid
   gint                selection_end;
   gint                dnd_cell;
 
-  GcalManager        *manager;
+  GcalContext        *context;
 };
 
 G_DEFINE_TYPE (GcalWeekGrid, gcal_week_grid, GTK_TYPE_CONTAINER);
@@ -131,7 +134,7 @@ get_event_range (GcalWeekGrid *self,
   if (!self->active_date)
     return;
 
-  week_start = get_start_of_week (self->active_date);
+  week_start = gcal_date_time_get_start_of_week (self->active_date);
   week_start_dst = g_date_time_is_daylight_savings (week_start);
 
   if (start)
@@ -270,7 +273,7 @@ gcal_week_grid_finalize (GObject *object)
   GcalWeekGrid *self = GCAL_WEEK_GRID (object);
 
   g_clear_pointer (&self->events, gcal_range_tree_unref);
-  g_clear_pointer (&self->active_date, g_free);
+  gcal_clear_date_time (&self->active_date);
 
   G_OBJECT_CLASS (gcal_week_grid_parent_class)->finalize (object);
 }
@@ -424,7 +427,7 @@ get_today_column (GcalWeekGrid *self)
   gint days_diff;
 
   today = g_date_time_new_now_local ();
-  week_start = get_start_of_week (self->active_date);
+  week_start = gcal_date_time_get_start_of_week (self->active_date);
   days_diff = g_date_time_difference (today, week_start) / G_TIME_SPAN_DAY;
 
   /* Today is out of range */
@@ -869,7 +872,7 @@ gcal_week_grid_button_release (GtkWidget      *widget,
 
   /* Fake the week view's event so we can control the X and Y values */
   weekview = gtk_widget_get_ancestor (widget, GCAL_TYPE_WEEK_VIEW);
-  week_start = get_start_of_week (self->active_date);
+  week_start = gcal_date_time_get_start_of_week (self->active_date);
 
   if (ltr)
     {
@@ -906,9 +909,9 @@ gcal_week_grid_button_release (GtkWidget      *widget,
                          (gdouble) out_x,
                          (gdouble) out_y);
 
-  gcal_clear_datetime (&week_start);
-  gcal_clear_datetime (&start);
-  gcal_clear_datetime (&end);
+  gcal_clear_date_time (&week_start);
+  gcal_clear_date_time (&start);
+  gcal_clear_date_time (&end);
 
   return GDK_EVENT_STOP;
 }
@@ -975,6 +978,7 @@ gcal_week_grid_drag_drop (GtkWidget      *widget,
   g_autoptr (GDateTime) week_start;
   g_autoptr (GDateTime) dnd_date;
   g_autoptr (GDateTime) new_end;
+  GcalCalendar *calendar;
   GtkWidget *event_widget;
   GcalEvent *event;
   ESource *source;
@@ -1007,7 +1011,8 @@ gcal_week_grid_drag_drop (GtkWidget      *widget,
     }
 
   event = gcal_event_widget_get_event (GCAL_EVENT_WIDGET (event_widget));
-  source = gcal_event_get_source (event);
+  calendar = gcal_event_get_calendar (event);
+  source = gcal_calendar_get_source (calendar);
 
   if (gcal_event_has_recurrence (event) &&
       !ask_recurrence_modification_type (widget, &mod, source))
@@ -1015,7 +1020,7 @@ gcal_week_grid_drag_drop (GtkWidget      *widget,
       goto out;
     }
 
-  week_start = get_start_of_week (self->active_date);
+  week_start = gcal_date_time_get_start_of_week (self->active_date);
   dnd_date = g_date_time_add_minutes (week_start, drop_cell * 30);
 
   /*
@@ -1038,7 +1043,7 @@ gcal_week_grid_drag_drop (GtkWidget      *widget,
 
   /* Commit the changes */
 
-  gcal_manager_update_event (self->manager, event, mod);
+  gcal_manager_update_event (gcal_context_get_manager (self->context), event, mod);
 
 out:
   /* Cancel the DnD */
@@ -1127,17 +1132,18 @@ gcal_week_grid_init (GcalWeekGrid *self)
 
 /* Public API */
 void
-gcal_week_grid_set_manager (GcalWeekGrid *self,
-                            GcalManager  *manager)
+gcal_week_grid_set_context (GcalWeekGrid *self,
+                            GcalContext  *context)
 {
   g_return_if_fail (GCAL_IS_WEEK_GRID (self));
 
-  self->manager = manager;
+  self->context = context;
 
-  g_signal_connect_swapped (gcal_manager_get_clock (manager),
-                            "minute-changed",
-                            G_CALLBACK (gtk_widget_queue_draw),
-                            self);
+  g_signal_connect_object (gcal_context_get_clock (context),
+                           "minute-changed",
+                           G_CALLBACK (gtk_widget_queue_draw),
+                           self,
+                           G_CONNECT_SWAPPED);
 }
 
 void
@@ -1155,6 +1161,7 @@ gcal_week_grid_add_event (GcalWeekGrid *self,
   g_object_ref (event);
 
   widget = g_object_new (GCAL_TYPE_EVENT_WIDGET,
+                         "context", self->context,
                          "event", event,
                          "orientation", GTK_ORIENTATION_VERTICAL,
                          NULL);
@@ -1251,10 +1258,9 @@ gcal_week_grid_clear_marks (GcalWeekGrid *self)
 
 void
 gcal_week_grid_set_date (GcalWeekGrid *self,
-                         icaltimetype *date)
+                         GDateTime    *date)
 {
-  g_clear_pointer (&self->active_date, g_free);
-  self->active_date = gcal_dup_icaltime (date);
+  gcal_set_date_time (&self->active_date, date);
 
   gtk_widget_queue_resize (GTK_WIDGET (self));
   gtk_widget_queue_draw (GTK_WIDGET (self));
