@@ -26,7 +26,6 @@
 #include "gcal-week-header.h"
 #include "gcal-week-grid.h"
 #include "gcal-week-view.h"
-#include "gcal-weather-service.h"
 
 #include <glib/gi18n.h>
 
@@ -49,12 +48,9 @@ struct _GcalWeekView
   GtkWidget          *scrolled_window;
   GtkWidget          *week_grid;
 
-  GcalTimeFormat      time_format;
-
   /* property */
-  icaltimetype       *date;
-  GcalManager        *manager;         /* owned */
-  GcalWeatherService *weather_service; /* owned */
+  GDateTime          *date;
+  GcalContext        *context;
 
   guint               scroll_grid_timeout_id;
 
@@ -71,9 +67,7 @@ enum
 {
   PROP_0,
   PROP_DATE,
-  PROP_MANAGER,
-  PROP_TIME_FORMAT,
-  PROP_WEATHER_SERVICE,
+  PROP_CONTEXT,
   NUM_PROPS
 };
 
@@ -135,11 +129,11 @@ update_grid_scroll_position (GcalWeekView *self)
     }
 
   now = g_date_time_new_now_local ();
-  week_start = get_start_of_week (self->date);
-  week_end = get_end_of_week (self->date);
+  week_start = gcal_date_time_get_start_of_week (self->date);
+  week_end = gcal_date_time_get_end_of_week (self->date);
 
   /* Don't animate when not today */
-  if (datetime_compare_date (now, week_start) < 0 || datetime_compare_date (now, week_end) >= 0)
+  if (gcal_date_time_compare_date (now, week_start) < 0 || gcal_date_time_compare_date (now, week_end) >= 0)
     GCAL_GOTO (out);
 
   vadjustment = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (self->scrolled_window));
@@ -179,7 +173,7 @@ schedule_position_scroll (GcalWeekView *self)
 }
 
 /* GcalView implementation */
-static icaltimetype*
+static GDateTime*
 gcal_week_view_get_date (GcalView *view)
 {
   GcalWeekView *self = GCAL_WEEK_VIEW (view);
@@ -188,15 +182,14 @@ gcal_week_view_get_date (GcalView *view)
 }
 
 static void
-gcal_week_view_set_date (GcalView     *view,
-                         icaltimetype *date)
+gcal_week_view_set_date (GcalView  *view,
+                         GDateTime *date)
 {
   GcalWeekView *self = GCAL_WEEK_VIEW (view);
 
   GCAL_ENTRY;
 
-  g_clear_pointer (&self->date, g_free);
-  self->date = gcal_dup_icaltime (date);
+  gcal_set_date_time (&self->date, date);
 
   /* Propagate the new date */
   gcal_week_grid_set_date (GCAL_WEEK_GRID (self->week_grid), date);
@@ -233,6 +226,47 @@ gcal_week_view_clear_marks (GcalView *view)
   gcal_week_grid_clear_marks (GCAL_WEEK_GRID (self->week_grid));
 }
 
+static void
+gcal_week_view_update_subscription (GcalView *view)
+{
+  g_autoptr (GDateTime) date_start = NULL;
+  g_autoptr (GDateTime) date_end = NULL;
+  GcalWeekView *self;
+  time_t range_start;
+  time_t range_end;
+
+  self = GCAL_WEEK_VIEW (view);
+  date_start = gcal_date_time_get_start_of_week (self->date);
+  range_start = g_date_time_to_unix (date_start);
+
+  date_end = gcal_date_time_get_end_of_week (self->date);
+  range_end = g_date_time_to_unix (date_end);
+
+  gcal_manager_set_subscriber (gcal_context_get_manager (self->context),
+                               E_CAL_DATA_MODEL_SUBSCRIBER (self),
+                               range_start,
+                               range_end);
+}
+
+static GDateTime*
+gcal_week_view_get_next_date (GcalView *view)
+{
+  GcalWeekView *self = GCAL_WEEK_VIEW (view);
+
+  g_assert (self->date != NULL);
+  return g_date_time_add_weeks (self->date, 1);
+}
+
+
+static GDateTime*
+gcal_week_view_get_previous_date (GcalView *view)
+{
+  GcalWeekView *self = GCAL_WEEK_VIEW (view);
+
+  g_assert (self->date != NULL);
+  return g_date_time_add_weeks (self->date, -1);
+}
+
 static void
 gcal_view_interface_init (GcalViewInterface *iface)
 {
@@ -240,6 +274,9 @@ gcal_view_interface_init (GcalViewInterface *iface)
   iface->set_date = gcal_week_view_set_date;
   iface->get_children_by_uuid = gcal_week_view_get_children_by_uuid;
   iface->clear_marks = gcal_week_view_clear_marks;
+  iface->update_subscription = gcal_week_view_update_subscription;
+  iface->get_next_date = gcal_week_view_get_next_date;
+  iface->get_previous_date = gcal_week_view_get_previous_date;
 }
 
 static void
@@ -305,10 +342,13 @@ gcal_week_view_component_added (ECalDataModelSubscriber *subscriber,
 {
   GcalWeekView *self = GCAL_WEEK_VIEW (subscriber);
   g_autoptr (GcalEvent) event = NULL;
+  GcalCalendar *calendar;
 
   GCAL_ENTRY;
 
-  event = gcal_event_new (e_client_get_source (E_CLIENT (client)), comp, NULL);
+  calendar = gcal_manager_get_calendar_from_source (gcal_context_get_manager (self->context),
+                                                    e_client_get_source (E_CLIENT (client)));
+  event = gcal_event_new (calendar, comp, NULL);
 
   if (gcal_event_is_multiday (event) || gcal_event_get_all_day (event))
     gcal_week_header_add_event (GCAL_WEEK_HEADER (self->header), event);
@@ -386,6 +426,7 @@ gcal_week_view_draw_hours (GcalWeekView *self,
                            GtkWidget    *widget)
 {
   GtkStyleContext *context;
+  GcalTimeFormat time_format;
   GtkStateFlags state;
   GtkBorder padding;
   GdkRGBA color;
@@ -397,6 +438,7 @@ gcal_week_view_draw_hours (GcalWeekView *self,
   PangoLayout *layout;
   PangoFontDescription *font_desc;
 
+  time_format = gcal_context_get_time_format (self->context);
   context = gtk_widget_get_style_context (widget);
   state = gtk_widget_get_state_flags (widget);
   ltr = gtk_widget_get_direction (widget) != GTK_TEXT_DIR_RTL;
@@ -421,7 +463,7 @@ gcal_week_view_draw_hours (GcalWeekView *self,
     {
       gchar *hours;
 
-      if (self->time_format == GCAL_TIME_FORMAT_24H)
+      if (time_format == GCAL_TIME_FORMAT_24H)
         {
           hours = g_strdup_printf ("%02d:00", i);
         }
@@ -506,8 +548,7 @@ gcal_week_view_finalize (GObject       *object)
 
   g_clear_pointer (&self->date, g_free);
 
-  g_clear_object (&self->manager);
-  g_clear_object (&self->weather_service);
+  g_clear_object (&self->context);
 
   /* Chain up to parent's finalize() method. */
   G_OBJECT_CLASS (gcal_week_view_parent_class)->finalize (object);
@@ -527,22 +568,19 @@ gcal_week_view_set_property (GObject       *object,
       gcal_view_set_date (GCAL_VIEW (object), g_value_get_boxed (value));
       break;
 
-    case PROP_MANAGER:
-      self->manager = g_value_dup_object (value);
+    case PROP_CONTEXT:
+      self->context = g_value_dup_object (value);
 
-      gcal_week_grid_set_manager (GCAL_WEEK_GRID (self->week_grid), self->manager);
-      gcal_week_header_set_manager (GCAL_WEEK_HEADER (self->header), self->manager);
-      g_object_notify (object, "manager");
-      break;
+      gcal_week_grid_set_context (GCAL_WEEK_GRID (self->week_grid), self->context);
+      gcal_week_header_set_context (GCAL_WEEK_HEADER (self->header), self->context);
 
-    case PROP_TIME_FORMAT:
-      self->time_format = g_value_get_enum (value);
-      gtk_widget_queue_draw (self->hours_bar);
-      break;
+      g_signal_connect_object (self->context,
+                               "notify::time-format",
+                               G_CALLBACK (gtk_widget_queue_draw),
+                               self->hours_bar,
+                               G_CONNECT_SWAPPED);
 
-    case PROP_WEATHER_SERVICE:
-      if (g_set_object (&self->weather_service, g_value_get_object (value)))
-        g_object_notify (object, "weather-service");
+      g_object_notify (object, "context");
       break;
 
     default:
@@ -568,16 +606,8 @@ gcal_week_view_get_property (GObject       *object,
       g_value_set_boxed (value, self->date);
       break;
 
-    case PROP_MANAGER:
-      g_value_set_object (value, self->manager);
-      break;
-
-    case PROP_TIME_FORMAT:
-      g_value_set_enum (value, self->time_format);
-      break;
-
-    case PROP_WEATHER_SERVICE:
-      g_value_set_object (value, self->weather_service);
+    case PROP_CONTEXT:
+      g_value_set_object (value, self->context);
       break;
 
     default:
@@ -600,17 +630,7 @@ gcal_week_view_class_init (GcalWeekViewClass *klass)
   object_class->get_property = gcal_week_view_get_property;
 
   g_object_class_override_property (object_class, PROP_DATE, "active-date");
-  g_object_class_override_property (object_class, PROP_MANAGER, "manager");
-  g_object_class_override_property (object_class, PROP_WEATHER_SERVICE, "weather-service");
-
-  g_object_class_install_property (object_class,
-                                   PROP_TIME_FORMAT,
-                                   g_param_spec_enum ("time-format",
-                                                      "Time format",
-                                                      "Time format",
-                                                      GCAL_TYPE_TIME_FORMAT,
-                                                      GCAL_TIME_FORMAT_24H,
-                                                      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+  g_object_class_override_property (object_class, PROP_CONTEXT, "context");
 
   gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/calendar/week-view.ui");
 
@@ -631,9 +651,5 @@ gcal_week_view_init (GcalWeekView *self)
   gtk_widget_init_template (GTK_WIDGET (self));
 
   update_hours_sidebar_size (self);
-
-  self->weather_service = NULL;
-
-  g_object_bind_property (self, "weather-service", self->header, "weather-service", G_BINDING_DEFAULT);
 }
 
